# djangorestframework-types [![PyPI](https://img.shields.io/pypi/v/djangorestframework-types.svg)](https://pypi.org/project/djangorestframework-types/)

Type stubs for [Django Rest Framework](https://www.django-rest-framework.org).

> Note: this project was forked from
> <https://github.com/typeddjango/djangorestframework-stubs> with the goal of
> removing the [`mypy`](https://github.com/python/mypy) plugin dependency so
> that `mypy` can't [crash due to Django
> config](https://github.com/typeddjango/django-stubs/issues/318), and that
> non-`mypy` type checkers like
> [`pyright`](https://github.com/microsoft/pyright) will work better with
> Django Rest Framework.

## install

```bash
pip install djangorestframework-types
```

## related

- <https://github.com/sbdchd/django-types>
